# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._enums import *

__all__ = [
    'RegisteredDomainDomainRegistration',
    'RegisteredDomainRegistrantChange',
    'RegisteredDomainTimeouts',
    'GetCertificateTimeoutsResult',
    'GetRegistrantChangeCheckExtendedAttributeResult',
    'GetRegistrantChangeCheckExtendedAttributeOptionResult',
]

@pulumi.output_type
class RegisteredDomainDomainRegistration(dict):
    def __init__(__self__, *,
                 id: Optional[builtins.int] = None,
                 period: Optional[builtins.int] = None,
                 state: Optional[builtins.str] = None):
        """
        :param builtins.int id: The ID of this resource.
        :param builtins.int period: The registration period in years.
        :param builtins.str state: The state of the domain.
        """
        if id is not None:
            pulumi.set(__self__, "id", id)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.int]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def period(self) -> Optional[builtins.int]:
        """
        The registration period in years.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter
    def state(self) -> Optional[builtins.str]:
        """
        The state of the domain.
        """
        return pulumi.get(self, "state")


@pulumi.output_type
class RegisteredDomainRegistrantChange(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accountId":
            suggest = "account_id"
        elif key == "contactId":
            suggest = "contact_id"
        elif key == "domainId":
            suggest = "domain_id"
        elif key == "extendedAttributes":
            suggest = "extended_attributes"
        elif key == "irtLockLiftedBy":
            suggest = "irt_lock_lifted_by"
        elif key == "registryOwnerChange":
            suggest = "registry_owner_change"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RegisteredDomainRegistrantChange. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RegisteredDomainRegistrantChange.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RegisteredDomainRegistrantChange.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 account_id: Optional[builtins.int] = None,
                 contact_id: Optional[builtins.int] = None,
                 domain_id: Optional[builtins.str] = None,
                 extended_attributes: Optional[Mapping[str, builtins.str]] = None,
                 id: Optional[builtins.int] = None,
                 irt_lock_lifted_by: Optional[builtins.str] = None,
                 registry_owner_change: Optional[builtins.bool] = None,
                 state: Optional[builtins.str] = None):
        """
        :param builtins.int account_id: DNSimple Account ID to which the registrant change belongs to
        :param builtins.int contact_id: The ID of the contact to be used for the domain registration. The contact ID can be changed after the domain has been registered. The change will result in a new registrant change this may result in a [60-day lock](https://support.dnsimple.com/articles/icann-60-day-lock-registrant-change/).
        :param builtins.str domain_id: DNSimple domain ID for which the registrant change is being performed
        :param Mapping[str, builtins.str] extended_attributes: A map of extended attributes to be set for the domain registration. To see if there are any required extended attributes for any TLD use our [Lists the TLD Extended Attributes API](https://developer.dnsimple.com/v2/tlds/#getTldExtendedAttributes). The values provided in the `extended_attributes` will also be sent when a registrant change is initiated as part of changing the `contact_id`.
        :param builtins.int id: The ID of this resource.
        :param builtins.str irt_lock_lifted_by: Date when the registrant change lock was lifted for the domain
        :param builtins.bool registry_owner_change: True if the registrant change will result in a registry owner change
        :param builtins.str state: The state of the domain.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if contact_id is not None:
            pulumi.set(__self__, "contact_id", contact_id)
        if domain_id is not None:
            pulumi.set(__self__, "domain_id", domain_id)
        if extended_attributes is not None:
            pulumi.set(__self__, "extended_attributes", extended_attributes)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if irt_lock_lifted_by is not None:
            pulumi.set(__self__, "irt_lock_lifted_by", irt_lock_lifted_by)
        if registry_owner_change is not None:
            pulumi.set(__self__, "registry_owner_change", registry_owner_change)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[builtins.int]:
        """
        DNSimple Account ID to which the registrant change belongs to
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="contactId")
    def contact_id(self) -> Optional[builtins.int]:
        """
        The ID of the contact to be used for the domain registration. The contact ID can be changed after the domain has been registered. The change will result in a new registrant change this may result in a [60-day lock](https://support.dnsimple.com/articles/icann-60-day-lock-registrant-change/).
        """
        return pulumi.get(self, "contact_id")

    @property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> Optional[builtins.str]:
        """
        DNSimple domain ID for which the registrant change is being performed
        """
        return pulumi.get(self, "domain_id")

    @property
    @pulumi.getter(name="extendedAttributes")
    def extended_attributes(self) -> Optional[Mapping[str, builtins.str]]:
        """
        A map of extended attributes to be set for the domain registration. To see if there are any required extended attributes for any TLD use our [Lists the TLD Extended Attributes API](https://developer.dnsimple.com/v2/tlds/#getTldExtendedAttributes). The values provided in the `extended_attributes` will also be sent when a registrant change is initiated as part of changing the `contact_id`.
        """
        return pulumi.get(self, "extended_attributes")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.int]:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="irtLockLiftedBy")
    def irt_lock_lifted_by(self) -> Optional[builtins.str]:
        """
        Date when the registrant change lock was lifted for the domain
        """
        return pulumi.get(self, "irt_lock_lifted_by")

    @property
    @pulumi.getter(name="registryOwnerChange")
    def registry_owner_change(self) -> Optional[builtins.bool]:
        """
        True if the registrant change will result in a registry owner change
        """
        return pulumi.get(self, "registry_owner_change")

    @property
    @pulumi.getter
    def state(self) -> Optional[builtins.str]:
        """
        The state of the domain.
        """
        return pulumi.get(self, "state")


@pulumi.output_type
class RegisteredDomainTimeouts(dict):
    def __init__(__self__, *,
                 create: Optional[builtins.str] = None,
                 delete: Optional[builtins.str] = None,
                 update: Optional[builtins.str] = None):
        """
        :param builtins.str create: Create timeout.
        :param builtins.str delete: Delete timeout (currently unused).
        :param builtins.str update: Update timeout.
        """
        if create is not None:
            pulumi.set(__self__, "create", create)
        if delete is not None:
            pulumi.set(__self__, "delete", delete)
        if update is not None:
            pulumi.set(__self__, "update", update)

    @property
    @pulumi.getter
    def create(self) -> Optional[builtins.str]:
        """
        Create timeout.
        """
        return pulumi.get(self, "create")

    @property
    @pulumi.getter
    def delete(self) -> Optional[builtins.str]:
        """
        Delete timeout (currently unused).
        """
        return pulumi.get(self, "delete")

    @property
    @pulumi.getter
    def update(self) -> Optional[builtins.str]:
        """
        Update timeout.
        """
        return pulumi.get(self, "update")


@pulumi.output_type
class GetCertificateTimeoutsResult(dict):
    def __init__(__self__, *,
                 read: Optional[builtins.str] = None):
        """
        :param builtins.str read: (String) - The timeout for the read operation e.g. `5m`
        """
        if read is not None:
            pulumi.set(__self__, "read", read)

    @property
    @pulumi.getter
    def read(self) -> Optional[builtins.str]:
        """
        (String) - The timeout for the read operation e.g. `5m`
        """
        return pulumi.get(self, "read")


@pulumi.output_type
class GetRegistrantChangeCheckExtendedAttributeResult(dict):
    def __init__(__self__, *,
                 description: builtins.str,
                 name: builtins.str,
                 options: Sequence['outputs.GetRegistrantChangeCheckExtendedAttributeOptionResult'],
                 required: builtins.bool):
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "options", options)
        pulumi.set(__self__, "required", required)

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def options(self) -> Sequence['outputs.GetRegistrantChangeCheckExtendedAttributeOptionResult']:
        return pulumi.get(self, "options")

    @property
    @pulumi.getter
    def required(self) -> builtins.bool:
        return pulumi.get(self, "required")


@pulumi.output_type
class GetRegistrantChangeCheckExtendedAttributeOptionResult(dict):
    def __init__(__self__, *,
                 description: builtins.str,
                 title: builtins.str,
                 value: builtins.str):
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "title", title)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def title(self) -> builtins.str:
        return pulumi.get(self, "title")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCertificateResult',
    'AwaitableGetCertificateResult',
    'get_certificate',
    'get_certificate_output',
]

@pulumi.output_type
class GetCertificateResult:
    """
    A collection of values returned by getCertificate.
    """
    def __init__(__self__, certificate_chains=None, certificate_id=None, domain=None, id=None, private_key=None, root_certificate=None, server_certificate=None, timeouts=None):
        if certificate_chains and not isinstance(certificate_chains, list):
            raise TypeError("Expected argument 'certificate_chains' to be a list")
        pulumi.set(__self__, "certificate_chains", certificate_chains)
        if certificate_id and not isinstance(certificate_id, int):
            raise TypeError("Expected argument 'certificate_id' to be a int")
        pulumi.set(__self__, "certificate_id", certificate_id)
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if private_key and not isinstance(private_key, str):
            raise TypeError("Expected argument 'private_key' to be a str")
        pulumi.set(__self__, "private_key", private_key)
        if root_certificate and not isinstance(root_certificate, str):
            raise TypeError("Expected argument 'root_certificate' to be a str")
        pulumi.set(__self__, "root_certificate", root_certificate)
        if server_certificate and not isinstance(server_certificate, str):
            raise TypeError("Expected argument 'server_certificate' to be a str")
        pulumi.set(__self__, "server_certificate", server_certificate)
        if timeouts and not isinstance(timeouts, dict):
            raise TypeError("Expected argument 'timeouts' to be a dict")
        pulumi.set(__self__, "timeouts", timeouts)

    @property
    @pulumi.getter(name="certificateChains")
    def certificate_chains(self) -> Sequence[builtins.str]:
        """
        A list of certificates that make up the chain
        """
        return pulumi.get(self, "certificate_chains")

    @property
    @pulumi.getter(name="certificateId")
    def certificate_id(self) -> builtins.int:
        return pulumi.get(self, "certificate_id")

    @property
    @pulumi.getter
    def domain(self) -> builtins.str:
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> builtins.str:
        """
        The corresponding Private Key for the SSL Certificate
        """
        return pulumi.get(self, "private_key")

    @property
    @pulumi.getter(name="rootCertificate")
    def root_certificate(self) -> builtins.str:
        """
        The Root Certificate of the issuing CA
        """
        return pulumi.get(self, "root_certificate")

    @property
    @pulumi.getter(name="serverCertificate")
    def server_certificate(self) -> builtins.str:
        """
        The SSL Certificate
        """
        return pulumi.get(self, "server_certificate")

    @property
    @pulumi.getter
    def timeouts(self) -> Optional['outputs.GetCertificateTimeoutsResult']:
        return pulumi.get(self, "timeouts")


class AwaitableGetCertificateResult(GetCertificateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCertificateResult(
            certificate_chains=self.certificate_chains,
            certificate_id=self.certificate_id,
            domain=self.domain,
            id=self.id,
            private_key=self.private_key,
            root_certificate=self.root_certificate,
            server_certificate=self.server_certificate,
            timeouts=self.timeouts)


def get_certificate(certificate_id: Optional[builtins.int] = None,
                    domain: Optional[builtins.str] = None,
                    timeouts: Optional[Union['GetCertificateTimeoutsArgs', 'GetCertificateTimeoutsArgsDict']] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCertificateResult:
    """
    Provides a DNSimple certificate data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_dnsimple as dnsimple

    foobar = dnsimple.get_certificate(domain=dnsimple_domain,
        certificate_id=dnsimple_certificate_id)
    ```


    :param builtins.int certificate_id: The ID of the SSL Certificate
    :param builtins.str domain: The domain of the SSL Certificate
    """
    __args__ = dict()
    __args__['certificateId'] = certificate_id
    __args__['domain'] = domain
    __args__['timeouts'] = timeouts
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('dnsimple:index/getCertificate:getCertificate', __args__, opts=opts, typ=GetCertificateResult).value

    return AwaitableGetCertificateResult(
        certificate_chains=pulumi.get(__ret__, 'certificate_chains'),
        certificate_id=pulumi.get(__ret__, 'certificate_id'),
        domain=pulumi.get(__ret__, 'domain'),
        id=pulumi.get(__ret__, 'id'),
        private_key=pulumi.get(__ret__, 'private_key'),
        root_certificate=pulumi.get(__ret__, 'root_certificate'),
        server_certificate=pulumi.get(__ret__, 'server_certificate'),
        timeouts=pulumi.get(__ret__, 'timeouts'))
def get_certificate_output(certificate_id: Optional[pulumi.Input[builtins.int]] = None,
                           domain: Optional[pulumi.Input[builtins.str]] = None,
                           timeouts: Optional[pulumi.Input[Optional[Union['GetCertificateTimeoutsArgs', 'GetCertificateTimeoutsArgsDict']]]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCertificateResult]:
    """
    Provides a DNSimple certificate data source.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_dnsimple as dnsimple

    foobar = dnsimple.get_certificate(domain=dnsimple_domain,
        certificate_id=dnsimple_certificate_id)
    ```


    :param builtins.int certificate_id: The ID of the SSL Certificate
    :param builtins.str domain: The domain of the SSL Certificate
    """
    __args__ = dict()
    __args__['certificateId'] = certificate_id
    __args__['domain'] = domain
    __args__['timeouts'] = timeouts
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('dnsimple:index/getCertificate:getCertificate', __args__, opts=opts, typ=GetCertificateResult)
    return __ret__.apply(lambda __response__: GetCertificateResult(
        certificate_chains=pulumi.get(__response__, 'certificate_chains'),
        certificate_id=pulumi.get(__response__, 'certificate_id'),
        domain=pulumi.get(__response__, 'domain'),
        id=pulumi.get(__response__, 'id'),
        private_key=pulumi.get(__response__, 'private_key'),
        root_certificate=pulumi.get(__response__, 'root_certificate'),
        server_certificate=pulumi.get(__response__, 'server_certificate'),
        timeouts=pulumi.get(__response__, 'timeouts')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DomainArgs', 'Domain']

@pulumi.input_type
class DomainArgs:
    def __init__(__self__, *,
                 name: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a Domain resource.
        :param pulumi.Input[builtins.str] name: The domain name to be created
               
               # Attributes Reference
        """
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        The domain name to be created

        # Attributes Reference
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _DomainState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.int]] = None,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 private_whois: Optional[pulumi.Input[builtins.bool]] = None,
                 registrant_id: Optional[pulumi.Input[builtins.int]] = None,
                 state: Optional[pulumi.Input[builtins.str]] = None,
                 unicode_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Domain resources.
        :param pulumi.Input[builtins.int] account_id: The account ID for the domain.
        :param pulumi.Input[builtins.bool] auto_renew: Whether the domain is set to auto-renew.
        :param pulumi.Input[builtins.str] name: The domain name to be created
               
               # Attributes Reference
        :param pulumi.Input[builtins.bool] private_whois: Whether the domain has WhoIs privacy enabled.
        :param pulumi.Input[builtins.int] registrant_id: The ID of the registrant (contact) for the domain.
        :param pulumi.Input[builtins.str] state: The state of the domain.
        :param pulumi.Input[builtins.str] unicode_name: The domain name in Unicode format.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if private_whois is not None:
            pulumi.set(__self__, "private_whois", private_whois)
        if registrant_id is not None:
            pulumi.set(__self__, "registrant_id", registrant_id)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if unicode_name is not None:
            pulumi.set(__self__, "unicode_name", unicode_name)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The account ID for the domain.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the domain is set to auto-renew.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The domain name to be created

        # Attributes Reference
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="privateWhois")
    def private_whois(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the domain has WhoIs privacy enabled.
        """
        return pulumi.get(self, "private_whois")

    @private_whois.setter
    def private_whois(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "private_whois", value)

    @property
    @pulumi.getter(name="registrantId")
    def registrant_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The ID of the registrant (contact) for the domain.
        """
        return pulumi.get(self, "registrant_id")

    @registrant_id.setter
    def registrant_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "registrant_id", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The state of the domain.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="unicodeName")
    def unicode_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The domain name in Unicode format.
        """
        return pulumi.get(self, "unicode_name")

    @unicode_name.setter
    def unicode_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "unicode_name", value)


@pulumi.type_token("dnsimple:index/domain:Domain")
class Domain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a DNSimple domain resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        # Create a domain
        foobar = dnsimple.Domain("foobar", name=dnsimple["domain"])
        ```

        ## Import

        DNSimple domains can be imported using their numeric record ID.

        bash

        ```sh
        $ pulumi import dnsimple:index/domain:Domain resource_name 5678
        ```

        The record ID can be found within [DNSimple Domains API](https://developer.dnsimple.com/v2/domains/#listDomains). Check out [Authentication](https://developer.dnsimple.com/v2/#authentication) in API Overview for available options.

        bash

        curl -u 'EMAIL:PASSWORD' https://api.dnsimple.com/v2/1234/domains?name_like=example.com | jq

        {

          "data": [

            {
            
              "id": 5678,
            
              "account_id": 1234,
            
              "registrant_id": null,
            
              "name": "example.com",
            
              "unicode_name": "example.com",
            
              "state": "hosted",
            
              "auto_renew": false,
            
              "private_whois": false,
            
              "expires_on": null,
            
              "expires_at": null,
            
              "created_at": "2021-10-01T00:00:00Z",
            
              "updated_at": "2021-10-01T00:00:00Z"
            
            }

          ],

          "pagination": {

            "current_page": 1,
            
            "per_page": 30,
            
            "total_entries": 1,
            
            "total_pages": 1

          }

        }

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: The domain name to be created
               
               # Attributes Reference
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DNSimple domain resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        # Create a domain
        foobar = dnsimple.Domain("foobar", name=dnsimple["domain"])
        ```

        ## Import

        DNSimple domains can be imported using their numeric record ID.

        bash

        ```sh
        $ pulumi import dnsimple:index/domain:Domain resource_name 5678
        ```

        The record ID can be found within [DNSimple Domains API](https://developer.dnsimple.com/v2/domains/#listDomains). Check out [Authentication](https://developer.dnsimple.com/v2/#authentication) in API Overview for available options.

        bash

        curl -u 'EMAIL:PASSWORD' https://api.dnsimple.com/v2/1234/domains?name_like=example.com | jq

        {

          "data": [

            {
            
              "id": 5678,
            
              "account_id": 1234,
            
              "registrant_id": null,
            
              "name": "example.com",
            
              "unicode_name": "example.com",
            
              "state": "hosted",
            
              "auto_renew": false,
            
              "private_whois": false,
            
              "expires_on": null,
            
              "expires_at": null,
            
              "created_at": "2021-10-01T00:00:00Z",
            
              "updated_at": "2021-10-01T00:00:00Z"
            
            }

          ],

          "pagination": {

            "current_page": 1,
            
            "per_page": 30,
            
            "total_entries": 1,
            
            "total_pages": 1

          }

        }

        :param str resource_name: The name of the resource.
        :param DomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DomainArgs.__new__(DomainArgs)

            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["account_id"] = None
            __props__.__dict__["auto_renew"] = None
            __props__.__dict__["private_whois"] = None
            __props__.__dict__["registrant_id"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["unicode_name"] = None
        super(Domain, __self__).__init__(
            'dnsimple:index/domain:Domain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.int]] = None,
            auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            private_whois: Optional[pulumi.Input[builtins.bool]] = None,
            registrant_id: Optional[pulumi.Input[builtins.int]] = None,
            state: Optional[pulumi.Input[builtins.str]] = None,
            unicode_name: Optional[pulumi.Input[builtins.str]] = None) -> 'Domain':
        """
        Get an existing Domain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] account_id: The account ID for the domain.
        :param pulumi.Input[builtins.bool] auto_renew: Whether the domain is set to auto-renew.
        :param pulumi.Input[builtins.str] name: The domain name to be created
               
               # Attributes Reference
        :param pulumi.Input[builtins.bool] private_whois: Whether the domain has WhoIs privacy enabled.
        :param pulumi.Input[builtins.int] registrant_id: The ID of the registrant (contact) for the domain.
        :param pulumi.Input[builtins.str] state: The state of the domain.
        :param pulumi.Input[builtins.str] unicode_name: The domain name in Unicode format.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DomainState.__new__(_DomainState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["auto_renew"] = auto_renew
        __props__.__dict__["name"] = name
        __props__.__dict__["private_whois"] = private_whois
        __props__.__dict__["registrant_id"] = registrant_id
        __props__.__dict__["state"] = state
        __props__.__dict__["unicode_name"] = unicode_name
        return Domain(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.int]:
        """
        The account ID for the domain.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> pulumi.Output[builtins.bool]:
        """
        Whether the domain is set to auto-renew.
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The domain name to be created

        # Attributes Reference
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="privateWhois")
    def private_whois(self) -> pulumi.Output[builtins.bool]:
        """
        Whether the domain has WhoIs privacy enabled.
        """
        return pulumi.get(self, "private_whois")

    @property
    @pulumi.getter(name="registrantId")
    def registrant_id(self) -> pulumi.Output[builtins.int]:
        """
        The ID of the registrant (contact) for the domain.
        """
        return pulumi.get(self, "registrant_id")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[builtins.str]:
        """
        The state of the domain.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="unicodeName")
    def unicode_name(self) -> pulumi.Output[builtins.str]:
        """
        The domain name in Unicode format.
        """
        return pulumi.get(self, "unicode_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DsRecordArgs', 'DsRecord']

@pulumi.input_type
class DsRecordArgs:
    def __init__(__self__, *,
                 algorithm: pulumi.Input[builtins.str],
                 domain: pulumi.Input[builtins.str],
                 digest: Optional[pulumi.Input[builtins.str]] = None,
                 digest_type: Optional[pulumi.Input[builtins.str]] = None,
                 keytag: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a DsRecord resource.
        :param pulumi.Input[builtins.str] algorithm: DNSSEC algorithm number as a string.
        :param pulumi.Input[builtins.str] domain: The domain name or numeric ID to create the delegation signer record for.
        :param pulumi.Input[builtins.str] digest: The hexidecimal representation of the digest of the corresponding DNSKEY record.
        :param pulumi.Input[builtins.str] digest_type: DNSSEC digest type number as a string.
        :param pulumi.Input[builtins.str] keytag: A keytag that references the corresponding DNSKEY record.
        :param pulumi.Input[builtins.str] public_key: A public key that references the corresponding DNSKEY record.
               
               # Attributes Reference
        """
        pulumi.set(__self__, "algorithm", algorithm)
        pulumi.set(__self__, "domain", domain)
        if digest is not None:
            pulumi.set(__self__, "digest", digest)
        if digest_type is not None:
            pulumi.set(__self__, "digest_type", digest_type)
        if keytag is not None:
            pulumi.set(__self__, "keytag", keytag)
        if public_key is not None:
            pulumi.set(__self__, "public_key", public_key)

    @property
    @pulumi.getter
    def algorithm(self) -> pulumi.Input[builtins.str]:
        """
        DNSSEC algorithm number as a string.
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "algorithm", value)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[builtins.str]:
        """
        The domain name or numeric ID to create the delegation signer record for.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def digest(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The hexidecimal representation of the digest of the corresponding DNSKEY record.
        """
        return pulumi.get(self, "digest")

    @digest.setter
    def digest(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "digest", value)

    @property
    @pulumi.getter(name="digestType")
    def digest_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNSSEC digest type number as a string.
        """
        return pulumi.get(self, "digest_type")

    @digest_type.setter
    def digest_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "digest_type", value)

    @property
    @pulumi.getter
    def keytag(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A keytag that references the corresponding DNSKEY record.
        """
        return pulumi.get(self, "keytag")

    @keytag.setter
    def keytag(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "keytag", value)

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A public key that references the corresponding DNSKEY record.

        # Attributes Reference
        """
        return pulumi.get(self, "public_key")

    @public_key.setter
    def public_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_key", value)


@pulumi.input_type
class _DsRecordState:
    def __init__(__self__, *,
                 algorithm: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 digest: Optional[pulumi.Input[builtins.str]] = None,
                 digest_type: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 keytag: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering DsRecord resources.
        :param pulumi.Input[builtins.str] algorithm: DNSSEC algorithm number as a string.
        :param pulumi.Input[builtins.str] created_at: The time the DS record was created at.
        :param pulumi.Input[builtins.str] digest: The hexidecimal representation of the digest of the corresponding DNSKEY record.
        :param pulumi.Input[builtins.str] digest_type: DNSSEC digest type number as a string.
        :param pulumi.Input[builtins.str] domain: The domain name or numeric ID to create the delegation signer record for.
        :param pulumi.Input[builtins.str] keytag: A keytag that references the corresponding DNSKEY record.
        :param pulumi.Input[builtins.str] public_key: A public key that references the corresponding DNSKEY record.
               
               # Attributes Reference
        :param pulumi.Input[builtins.str] updated_at: The time the DS record was last updated at.
        """
        if algorithm is not None:
            pulumi.set(__self__, "algorithm", algorithm)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if digest is not None:
            pulumi.set(__self__, "digest", digest)
        if digest_type is not None:
            pulumi.set(__self__, "digest_type", digest_type)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if keytag is not None:
            pulumi.set(__self__, "keytag", keytag)
        if public_key is not None:
            pulumi.set(__self__, "public_key", public_key)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def algorithm(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNSSEC algorithm number as a string.
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "algorithm", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time the DS record was created at.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def digest(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The hexidecimal representation of the digest of the corresponding DNSKEY record.
        """
        return pulumi.get(self, "digest")

    @digest.setter
    def digest(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "digest", value)

    @property
    @pulumi.getter(name="digestType")
    def digest_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNSSEC digest type number as a string.
        """
        return pulumi.get(self, "digest_type")

    @digest_type.setter
    def digest_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "digest_type", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The domain name or numeric ID to create the delegation signer record for.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def keytag(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A keytag that references the corresponding DNSKEY record.
        """
        return pulumi.get(self, "keytag")

    @keytag.setter
    def keytag(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "keytag", value)

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A public key that references the corresponding DNSKEY record.

        # Attributes Reference
        """
        return pulumi.get(self, "public_key")

    @public_key.setter
    def public_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_key", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time the DS record was last updated at.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("dnsimple:index/dsRecord:DsRecord")
class DsRecord(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 algorithm: Optional[pulumi.Input[builtins.str]] = None,
                 digest: Optional[pulumi.Input[builtins.str]] = None,
                 digest_type: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 keytag: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a DNSimple domain delegation signer record resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        foobar = dnsimple.DsRecord("foobar",
            domain=dnsimple["domain"],
            algorithm="8",
            digest="6CEEA0117A02480216EBF745A7B690F938860074E4AD11AF2AC573007205682B",
            digest_type="2",
            key_tag="12345")
        ```

        ## Import

        DNSimple DS record resources can be imported using their domain ID and numeric record ID.

        bash

        ```sh
        $ pulumi import dnsimple:index/dsRecord:DsRecord resource_name example.com_5678
        ```

        The record ID can be found within [DNSimple DNSSEC API](https://developer.dnsimple.com/v2/domains/dnssec/#listDomainDelegationSignerRecords). Check out [Authentication](https://developer.dnsimple.com/v2/#authentication) in API Overview for available options.

        bash

        curl -u 'EMAIL:PASSWORD' https://api.dnsimple.com/v2/1010/domains/example.com/ds_records | jq

        {

          "data": [

            {
            
              "id": 24,
            
              "domain_id": 1010,
            
              "algorithm": "8",
            
              "digest": "C1F6E04A5A61FBF65BF9DC8294C363CF11C89E802D926BDAB79C55D27BEFA94F",
            
              "digest_type": "2",
            
              "keytag": "44620",
            
              "public_key": null,
            
              "created_at": "2017-03-03T13:49:58Z",
            
              "updated_at": "2017-03-03T13:49:58Z"
            
            }

          ],

          "pagination": {

            "current_page": 1,
            
            "per_page": 30,
            
            "total_entries": 1,
            
            "total_pages": 1

          }

        }

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] algorithm: DNSSEC algorithm number as a string.
        :param pulumi.Input[builtins.str] digest: The hexidecimal representation of the digest of the corresponding DNSKEY record.
        :param pulumi.Input[builtins.str] digest_type: DNSSEC digest type number as a string.
        :param pulumi.Input[builtins.str] domain: The domain name or numeric ID to create the delegation signer record for.
        :param pulumi.Input[builtins.str] keytag: A keytag that references the corresponding DNSKEY record.
        :param pulumi.Input[builtins.str] public_key: A public key that references the corresponding DNSKEY record.
               
               # Attributes Reference
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DsRecordArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DNSimple domain delegation signer record resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        foobar = dnsimple.DsRecord("foobar",
            domain=dnsimple["domain"],
            algorithm="8",
            digest="6CEEA0117A02480216EBF745A7B690F938860074E4AD11AF2AC573007205682B",
            digest_type="2",
            key_tag="12345")
        ```

        ## Import

        DNSimple DS record resources can be imported using their domain ID and numeric record ID.

        bash

        ```sh
        $ pulumi import dnsimple:index/dsRecord:DsRecord resource_name example.com_5678
        ```

        The record ID can be found within [DNSimple DNSSEC API](https://developer.dnsimple.com/v2/domains/dnssec/#listDomainDelegationSignerRecords). Check out [Authentication](https://developer.dnsimple.com/v2/#authentication) in API Overview for available options.

        bash

        curl -u 'EMAIL:PASSWORD' https://api.dnsimple.com/v2/1010/domains/example.com/ds_records | jq

        {

          "data": [

            {
            
              "id": 24,
            
              "domain_id": 1010,
            
              "algorithm": "8",
            
              "digest": "C1F6E04A5A61FBF65BF9DC8294C363CF11C89E802D926BDAB79C55D27BEFA94F",
            
              "digest_type": "2",
            
              "keytag": "44620",
            
              "public_key": null,
            
              "created_at": "2017-03-03T13:49:58Z",
            
              "updated_at": "2017-03-03T13:49:58Z"
            
            }

          ],

          "pagination": {

            "current_page": 1,
            
            "per_page": 30,
            
            "total_entries": 1,
            
            "total_pages": 1

          }

        }

        :param str resource_name: The name of the resource.
        :param DsRecordArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DsRecordArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 algorithm: Optional[pulumi.Input[builtins.str]] = None,
                 digest: Optional[pulumi.Input[builtins.str]] = None,
                 digest_type: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 keytag: Optional[pulumi.Input[builtins.str]] = None,
                 public_key: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DsRecordArgs.__new__(DsRecordArgs)

            if algorithm is None and not opts.urn:
                raise TypeError("Missing required property 'algorithm'")
            __props__.__dict__["algorithm"] = algorithm
            __props__.__dict__["digest"] = digest
            __props__.__dict__["digest_type"] = digest_type
            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            __props__.__dict__["keytag"] = keytag
            __props__.__dict__["public_key"] = public_key
            __props__.__dict__["created_at"] = None
            __props__.__dict__["updated_at"] = None
        super(DsRecord, __self__).__init__(
            'dnsimple:index/dsRecord:DsRecord',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            algorithm: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            digest: Optional[pulumi.Input[builtins.str]] = None,
            digest_type: Optional[pulumi.Input[builtins.str]] = None,
            domain: Optional[pulumi.Input[builtins.str]] = None,
            keytag: Optional[pulumi.Input[builtins.str]] = None,
            public_key: Optional[pulumi.Input[builtins.str]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None) -> 'DsRecord':
        """
        Get an existing DsRecord resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] algorithm: DNSSEC algorithm number as a string.
        :param pulumi.Input[builtins.str] created_at: The time the DS record was created at.
        :param pulumi.Input[builtins.str] digest: The hexidecimal representation of the digest of the corresponding DNSKEY record.
        :param pulumi.Input[builtins.str] digest_type: DNSSEC digest type number as a string.
        :param pulumi.Input[builtins.str] domain: The domain name or numeric ID to create the delegation signer record for.
        :param pulumi.Input[builtins.str] keytag: A keytag that references the corresponding DNSKEY record.
        :param pulumi.Input[builtins.str] public_key: A public key that references the corresponding DNSKEY record.
               
               # Attributes Reference
        :param pulumi.Input[builtins.str] updated_at: The time the DS record was last updated at.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DsRecordState.__new__(_DsRecordState)

        __props__.__dict__["algorithm"] = algorithm
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["digest"] = digest
        __props__.__dict__["digest_type"] = digest_type
        __props__.__dict__["domain"] = domain
        __props__.__dict__["keytag"] = keytag
        __props__.__dict__["public_key"] = public_key
        __props__.__dict__["updated_at"] = updated_at
        return DsRecord(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def algorithm(self) -> pulumi.Output[builtins.str]:
        """
        DNSSEC algorithm number as a string.
        """
        return pulumi.get(self, "algorithm")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        The time the DS record was created at.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def digest(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The hexidecimal representation of the digest of the corresponding DNSKEY record.
        """
        return pulumi.get(self, "digest")

    @property
    @pulumi.getter(name="digestType")
    def digest_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        DNSSEC digest type number as a string.
        """
        return pulumi.get(self, "digest_type")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[builtins.str]:
        """
        The domain name or numeric ID to create the delegation signer record for.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter
    def keytag(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A keytag that references the corresponding DNSKEY record.
        """
        return pulumi.get(self, "keytag")

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A public key that references the corresponding DNSKEY record.

        # Attributes Reference
        """
        return pulumi.get(self, "public_key")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        The time the DS record was last updated at.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['LetsEncryptCertificateArgs', 'LetsEncryptCertificate']

@pulumi.input_type
class LetsEncryptCertificateArgs:
    def __init__(__self__, *,
                 auto_renew: pulumi.Input[builtins.bool],
                 domain_id: pulumi.Input[builtins.str],
                 name: pulumi.Input[builtins.str],
                 alternate_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 signature_algorithm: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a LetsEncryptCertificate resource.
        :param pulumi.Input[builtins.bool] auto_renew: True if the certificate should auto-renew
        :param pulumi.Input[builtins.str] domain_id: The domain to be issued the certificate for
        :param pulumi.Input[builtins.str] name: The certificate name; use `""` for the root domain. Wildcard names are supported.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] alternate_names: The certificate alternate names
        :param pulumi.Input[builtins.str] signature_algorithm: The signature algorithm to use for the certificate
        """
        pulumi.set(__self__, "auto_renew", auto_renew)
        pulumi.set(__self__, "domain_id", domain_id)
        pulumi.set(__self__, "name", name)
        if alternate_names is not None:
            pulumi.set(__self__, "alternate_names", alternate_names)
        if signature_algorithm is not None:
            pulumi.set(__self__, "signature_algorithm", signature_algorithm)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> pulumi.Input[builtins.bool]:
        """
        True if the certificate should auto-renew
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: pulumi.Input[builtins.bool]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> pulumi.Input[builtins.str]:
        """
        The domain to be issued the certificate for
        """
        return pulumi.get(self, "domain_id")

    @domain_id.setter
    def domain_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "domain_id", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        The certificate name; use `""` for the root domain. Wildcard names are supported.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="alternateNames")
    def alternate_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The certificate alternate names
        """
        return pulumi.get(self, "alternate_names")

    @alternate_names.setter
    def alternate_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "alternate_names", value)

    @property
    @pulumi.getter(name="signatureAlgorithm")
    def signature_algorithm(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The signature algorithm to use for the certificate
        """
        return pulumi.get(self, "signature_algorithm")

    @signature_algorithm.setter
    def signature_algorithm(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "signature_algorithm", value)


@pulumi.input_type
class _LetsEncryptCertificateState:
    def __init__(__self__, *,
                 alternate_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 authority_identifier: Optional[pulumi.Input[builtins.str]] = None,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 csr: Optional[pulumi.Input[builtins.str]] = None,
                 domain_id: Optional[pulumi.Input[builtins.str]] = None,
                 expires_at: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 signature_algorithm: Optional[pulumi.Input[builtins.str]] = None,
                 state: Optional[pulumi.Input[builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None,
                 years: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering LetsEncryptCertificate resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] alternate_names: The certificate alternate names
        :param pulumi.Input[builtins.str] authority_identifier: The identifying certification authority (CA)
        :param pulumi.Input[builtins.bool] auto_renew: True if the certificate should auto-renew
        :param pulumi.Input[builtins.str] created_at: The datetime the certificate was created
        :param pulumi.Input[builtins.str] csr: The certificate signing request
        :param pulumi.Input[builtins.str] domain_id: The domain to be issued the certificate for
        :param pulumi.Input[builtins.str] expires_at: The datetime the certificate will expire
        :param pulumi.Input[builtins.str] name: The certificate name; use `""` for the root domain. Wildcard names are supported.
        :param pulumi.Input[builtins.str] signature_algorithm: The signature algorithm to use for the certificate
        :param pulumi.Input[builtins.str] state: The state of the certificate
        :param pulumi.Input[builtins.str] updated_at: The datetime the certificate was last updated
        :param pulumi.Input[builtins.int] years: The years the certificate will last
        """
        if alternate_names is not None:
            pulumi.set(__self__, "alternate_names", alternate_names)
        if authority_identifier is not None:
            pulumi.set(__self__, "authority_identifier", authority_identifier)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if csr is not None:
            pulumi.set(__self__, "csr", csr)
        if domain_id is not None:
            pulumi.set(__self__, "domain_id", domain_id)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if signature_algorithm is not None:
            pulumi.set(__self__, "signature_algorithm", signature_algorithm)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if years is not None:
            pulumi.set(__self__, "years", years)

    @property
    @pulumi.getter(name="alternateNames")
    def alternate_names(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The certificate alternate names
        """
        return pulumi.get(self, "alternate_names")

    @alternate_names.setter
    def alternate_names(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "alternate_names", value)

    @property
    @pulumi.getter(name="authorityIdentifier")
    def authority_identifier(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The identifying certification authority (CA)
        """
        return pulumi.get(self, "authority_identifier")

    @authority_identifier.setter
    def authority_identifier(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authority_identifier", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        True if the certificate should auto-renew
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The datetime the certificate was created
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def csr(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate signing request
        """
        return pulumi.get(self, "csr")

    @csr.setter
    def csr(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "csr", value)

    @property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The domain to be issued the certificate for
        """
        return pulumi.get(self, "domain_id")

    @domain_id.setter
    def domain_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain_id", value)

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The datetime the certificate will expire
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The certificate name; use `""` for the root domain. Wildcard names are supported.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="signatureAlgorithm")
    def signature_algorithm(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The signature algorithm to use for the certificate
        """
        return pulumi.get(self, "signature_algorithm")

    @signature_algorithm.setter
    def signature_algorithm(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "signature_algorithm", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The state of the certificate
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The datetime the certificate was last updated
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def years(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The years the certificate will last
        """
        return pulumi.get(self, "years")

    @years.setter
    def years(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "years", value)


@pulumi.type_token("dnsimple:index/letsEncryptCertificate:LetsEncryptCertificate")
class LetsEncryptCertificate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alternate_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 domain_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 signature_algorithm: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a DNSimple Let's Encrypt certificate resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        foobar = dnsimple.LetsEncryptCertificate("foobar",
            domain_id=dnsimple["domainId"],
            auto_renew=False,
            name="www",
            alternate_names=[
                "docs.example.com",
                "status.example.com",
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] alternate_names: The certificate alternate names
        :param pulumi.Input[builtins.bool] auto_renew: True if the certificate should auto-renew
        :param pulumi.Input[builtins.str] domain_id: The domain to be issued the certificate for
        :param pulumi.Input[builtins.str] name: The certificate name; use `""` for the root domain. Wildcard names are supported.
        :param pulumi.Input[builtins.str] signature_algorithm: The signature algorithm to use for the certificate
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LetsEncryptCertificateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DNSimple Let's Encrypt certificate resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        foobar = dnsimple.LetsEncryptCertificate("foobar",
            domain_id=dnsimple["domainId"],
            auto_renew=False,
            name="www",
            alternate_names=[
                "docs.example.com",
                "status.example.com",
            ])
        ```

        :param str resource_name: The name of the resource.
        :param LetsEncryptCertificateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LetsEncryptCertificateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alternate_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
                 domain_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 signature_algorithm: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LetsEncryptCertificateArgs.__new__(LetsEncryptCertificateArgs)

            __props__.__dict__["alternate_names"] = alternate_names
            if auto_renew is None and not opts.urn:
                raise TypeError("Missing required property 'auto_renew'")
            __props__.__dict__["auto_renew"] = auto_renew
            if domain_id is None and not opts.urn:
                raise TypeError("Missing required property 'domain_id'")
            __props__.__dict__["domain_id"] = domain_id
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["signature_algorithm"] = signature_algorithm
            __props__.__dict__["authority_identifier"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["csr"] = None
            __props__.__dict__["expires_at"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["updated_at"] = None
            __props__.__dict__["years"] = None
        super(LetsEncryptCertificate, __self__).__init__(
            'dnsimple:index/letsEncryptCertificate:LetsEncryptCertificate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alternate_names: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            authority_identifier: Optional[pulumi.Input[builtins.str]] = None,
            auto_renew: Optional[pulumi.Input[builtins.bool]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            csr: Optional[pulumi.Input[builtins.str]] = None,
            domain_id: Optional[pulumi.Input[builtins.str]] = None,
            expires_at: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            signature_algorithm: Optional[pulumi.Input[builtins.str]] = None,
            state: Optional[pulumi.Input[builtins.str]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None,
            years: Optional[pulumi.Input[builtins.int]] = None) -> 'LetsEncryptCertificate':
        """
        Get an existing LetsEncryptCertificate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] alternate_names: The certificate alternate names
        :param pulumi.Input[builtins.str] authority_identifier: The identifying certification authority (CA)
        :param pulumi.Input[builtins.bool] auto_renew: True if the certificate should auto-renew
        :param pulumi.Input[builtins.str] created_at: The datetime the certificate was created
        :param pulumi.Input[builtins.str] csr: The certificate signing request
        :param pulumi.Input[builtins.str] domain_id: The domain to be issued the certificate for
        :param pulumi.Input[builtins.str] expires_at: The datetime the certificate will expire
        :param pulumi.Input[builtins.str] name: The certificate name; use `""` for the root domain. Wildcard names are supported.
        :param pulumi.Input[builtins.str] signature_algorithm: The signature algorithm to use for the certificate
        :param pulumi.Input[builtins.str] state: The state of the certificate
        :param pulumi.Input[builtins.str] updated_at: The datetime the certificate was last updated
        :param pulumi.Input[builtins.int] years: The years the certificate will last
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LetsEncryptCertificateState.__new__(_LetsEncryptCertificateState)

        __props__.__dict__["alternate_names"] = alternate_names
        __props__.__dict__["authority_identifier"] = authority_identifier
        __props__.__dict__["auto_renew"] = auto_renew
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["csr"] = csr
        __props__.__dict__["domain_id"] = domain_id
        __props__.__dict__["expires_at"] = expires_at
        __props__.__dict__["name"] = name
        __props__.__dict__["signature_algorithm"] = signature_algorithm
        __props__.__dict__["state"] = state
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["years"] = years
        return LetsEncryptCertificate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="alternateNames")
    def alternate_names(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        The certificate alternate names
        """
        return pulumi.get(self, "alternate_names")

    @property
    @pulumi.getter(name="authorityIdentifier")
    def authority_identifier(self) -> pulumi.Output[builtins.str]:
        """
        The identifying certification authority (CA)
        """
        return pulumi.get(self, "authority_identifier")

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> pulumi.Output[builtins.bool]:
        """
        True if the certificate should auto-renew
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        The datetime the certificate was created
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def csr(self) -> pulumi.Output[builtins.str]:
        """
        The certificate signing request
        """
        return pulumi.get(self, "csr")

    @property
    @pulumi.getter(name="domainId")
    def domain_id(self) -> pulumi.Output[builtins.str]:
        """
        The domain to be issued the certificate for
        """
        return pulumi.get(self, "domain_id")

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> pulumi.Output[builtins.str]:
        """
        The datetime the certificate will expire
        """
        return pulumi.get(self, "expires_at")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The certificate name; use `""` for the root domain. Wildcard names are supported.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="signatureAlgorithm")
    def signature_algorithm(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The signature algorithm to use for the certificate
        """
        return pulumi.get(self, "signature_algorithm")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[builtins.str]:
        """
        The state of the certificate
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        The datetime the certificate was last updated
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def years(self) -> pulumi.Output[builtins.int]:
        """
        The years the certificate will last
        """
        return pulumi.get(self, "years")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('dnsimple')


class _ExportableConfig(types.ModuleType):
    @property
    def account(self) -> Optional[str]:
        """
        The account for API operations.
        """
        return __config__.get('account')

    @property
    def prefetch(self) -> Optional[bool]:
        """
        Flag to enable the prefetch of zone records.
        """
        return __config__.get_bool('prefetch')

    @property
    def sandbox(self) -> Optional[bool]:
        """
        Flag to enable the sandbox API.
        """
        return __config__.get_bool('sandbox')

    @property
    def token(self) -> Optional[str]:
        """
        The API v2 token for API operations.
        """
        return __config__.get('token')

    @property
    def user_agent(self) -> Optional[str]:
        """
        Custom string to append to the user agent used for sending HTTP requests to the API.
        """
        return __config__.get('userAgent')




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DomainDelegationArgs', 'DomainDelegation']

@pulumi.input_type
class DomainDelegationArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[builtins.str],
                 name_servers: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        """
        The set of arguments for constructing a DomainDelegation resource.
        :param pulumi.Input[builtins.str] domain: The domain name.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] name_servers: The list of name servers to delegate to.
               
               # Attributes Reference
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "name_servers", name_servers)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[builtins.str]:
        """
        The domain name.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        The list of name servers to delegate to.

        # Attributes Reference
        """
        return pulumi.get(self, "name_servers")

    @name_servers.setter
    def name_servers(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "name_servers", value)


@pulumi.input_type
class _DomainDelegationState:
    def __init__(__self__, *,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 name_servers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering DomainDelegation resources.
        :param pulumi.Input[builtins.str] domain: The domain name.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] name_servers: The list of name servers to delegate to.
               
               # Attributes Reference
        """
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if name_servers is not None:
            pulumi.set(__self__, "name_servers", name_servers)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The domain name.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The list of name servers to delegate to.

        # Attributes Reference
        """
        return pulumi.get(self, "name_servers")

    @name_servers.setter
    def name_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "name_servers", value)


@pulumi.type_token("dnsimple:index/domainDelegation:DomainDelegation")
class DomainDelegation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 name_servers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        # Create a domain delegation
        foobar = dnsimple.DomainDelegation("foobar",
            domain=dnsimple["domain"],
            name_servers=[
                "ns1.example.org",
                "ns2.example.com",
            ])
        ```

        ## Import

        DNSimple domain delegations can be imported using the domain name.

        **Importing domain delegation for example.com**

        bash

        ```sh
        $ pulumi import dnsimple:index/domainDelegation:DomainDelegation resource_name example.com
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] domain: The domain name.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] name_servers: The list of name servers to delegate to.
               
               # Attributes Reference
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DomainDelegationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_dnsimple as dnsimple

        # Create a domain delegation
        foobar = dnsimple.DomainDelegation("foobar",
            domain=dnsimple["domain"],
            name_servers=[
                "ns1.example.org",
                "ns2.example.com",
            ])
        ```

        ## Import

        DNSimple domain delegations can be imported using the domain name.

        **Importing domain delegation for example.com**

        bash

        ```sh
        $ pulumi import dnsimple:index/domainDelegation:DomainDelegation resource_name example.com
        ```

        :param str resource_name: The name of the resource.
        :param DomainDelegationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DomainDelegationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 name_servers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DomainDelegationArgs.__new__(DomainDelegationArgs)

            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            if name_servers is None and not opts.urn:
                raise TypeError("Missing required property 'name_servers'")
            __props__.__dict__["name_servers"] = name_servers
        super(DomainDelegation, __self__).__init__(
            'dnsimple:index/domainDelegation:DomainDelegation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            domain: Optional[pulumi.Input[builtins.str]] = None,
            name_servers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'DomainDelegation':
        """
        Get an existing DomainDelegation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] domain: The domain name.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] name_servers: The list of name servers to delegate to.
               
               # Attributes Reference
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DomainDelegationState.__new__(_DomainDelegationState)

        __props__.__dict__["domain"] = domain
        __props__.__dict__["name_servers"] = name_servers
        return DomainDelegation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[builtins.str]:
        """
        The domain name.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        The list of name servers to delegate to.

        # Attributes Reference
        """
        return pulumi.get(self, "name_servers")

